package com.chenyang.nse.bussiness.service.core.charts.impl;

import com.chenyang.nse.bussiness.dao.table.core.findcharts.EchartsFiveDao;
import com.chenyang.nse.bussiness.dao.table.core.findcharts.EchartsFourDao;
import com.chenyang.nse.bussiness.dao.table.core.findcharts.EchartsOneDao;
import com.chenyang.nse.bussiness.dao.table.core.findcharts.EchartsSevenDao;
import com.chenyang.nse.bussiness.dao.table.core.findcharts.EchartsSixDao;
import com.chenyang.nse.bussiness.dao.table.core.findcharts.EchartsThreeDao;
import com.chenyang.nse.bussiness.dao.table.core.findcharts.EchartsTwoDao;
import com.chenyang.nse.bussiness.entity.orm.table.core.findCharts.EchartsOne;
import com.chenyang.nse.bussiness.service.core.charts.FindEchartsService;
import java.util.List;
import java.util.Map;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service
@Transactional
public class FindEchartsServiceImpl implements FindEchartsService {
   @Autowired
   private EchartsOneDao echartsOneDao;
   @Autowired
   private EchartsTwoDao echartsTwoDao;
   @Autowired
   private EchartsThreeDao echartsThreeDao;
   @Autowired
   private EchartsFourDao echartsFourDao;
   @Autowired
   private EchartsFiveDao echartsFiveDao;
   @Autowired
   private EchartsSixDao echartsSixDao;
   @Autowired
   private EchartsSevenDao echartsSevenDao;

   public List<Map<String, Object>> findNameByTaskidOne(String taskid) {
      List<Map<String, Object>> list1 = this.echartsOneDao.findNameByTaskid(taskid);
      return list1;
   }

   public List<Map<String, Object>> findNameByTaskidTwo(String taskid) {
      List<Map<String, Object>> list2 = this.echartsTwoDao.findNameByPieTaskid(taskid);
      return list2;
   }

   public List<Map<String, Object>> findNameByVersionidThree(String taskid) {
      List<Map<String, Object>> list3 = this.echartsThreeDao.findNameByVersionid(taskid);
      return list3;
   }

   public List<Map<String, Object>> findNameByTaskidFour(String taskid) {
      List<Map<String, Object>> list4 = this.echartsFourDao.findNameByTaskid(taskid);
      return list4;
   }

   public List<Map<String, Object>> findNameByVersionidFive(String taskid) {
      List<Map<String, Object>> list5 = this.echartsFiveDao.findNameByVersionid(taskid);
      return list5;
   }

   public List<Map<String, Object>> findNameByTaskidSix(String taskid) {
      List<Map<String, Object>> list6 = this.echartsSixDao.findNameByTaskid(taskid);
      return list6;
   }

   public List<Map<String, Object>> findNameByTaskidSeven(String taskid) {
      List<Map<String, Object>> list7 = this.echartsSevenDao.findNameByTaskid(taskid);
      return list7;
   }

   public List<EchartsOne> findAllTaskid() {
      List<EchartsOne> list = this.echartsOneDao.findAllTaskid();
      return list;
   }

   public List<Map<String, Object>> findAll() {
      return this.echartsFourDao.findNameAll();
   }

   public List<Map<String, Object>> findNameByTask(String taskid) {
      List<Map<String, Object>> listTaskName = this.echartsFiveDao.findNameByTask(taskid);
      return listTaskName;
   }
}
