package com.chenyang.nse.bussiness.service.core.charts;

import com.chenyang.nse.bussiness.entity.orm.table.core.findCharts.EchartsOne;
import java.util.List;
import java.util.Map;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service
@Transactional
public interface FindEchartsService {
   List<Map<String, Object>> findNameByTaskidOne(String taskid);

   List<Map<String, Object>> findNameByTaskidTwo(String taskid);

   List<Map<String, Object>> findNameByVersionidThree(String taskid);

   List<Map<String, Object>> findNameByTaskidFour(String taskid);

   List<Map<String, Object>> findNameByVersionidFive(String taskid);

   List<Map<String, Object>> findNameByTaskidSix(String taskid);

   List<Map<String, Object>> findNameByTaskidSeven(String taskid);

   List<EchartsOne> findAllTaskid();

   List<Map<String, Object>> findAll();

   List<Map<String, Object>> findNameByTask(String taskid);
}
